@@ -15,14 +15,11 @@ class V83145 < Formula
     system 'make dependencies'
     system 'make', 'native',
                    "-j#{ENV.make_jobs}",
-                   "library=shared",
-                   "snapshot=on",
-                   "console=readline"
+                   "snapshot=on"
 
     prefix.install 'include'
     cd 'out/native' do
       lib.install Dir['lib*']
-      bin.install 'd8', 'lineprocessor', 'mksnapshot', 'preparser', 'process', 'shell' => 'v8'
     end
   end
 end
